@@ -5,7 +5,16 @@ import networkx as nx
 import pandas as pd
 from networkx.algorithms import bipartite
 from numpy import matrix, ndarray
-from scipy.sparse import coo_matrix, csc_matrix, csr_matrix, lil_matrix
+from scipy.sparse import (
+    coo_array,
+    coo_matrix,
+    csc_array,
+    csc_matrix,
+    csr_array,
+    csr_matrix,
+    lil_array,
+    lil_matrix,
+)
 
 from .classes import (
     Hypergraph,
@@ -27,6 +36,7 @@ __all__ = [
     "from_hyperedge_dict",
     "to_hyperedge_dict",
     "from_bipartite_pandas_dataframe",
+    "to_bipartite_pandas_dataframe",
     "from_incidence_matrix",
     "from_simplicial_complex_to_hypergraph",
     "to_incidence_matrix",
@@ -83,7 +93,19 @@ def convert_to_hypergraph(data, create_using=None):
         from_hyperedge_dict(data, create_using)
 
     elif isinstance(
-        data, (ndarray, matrix, csr_matrix, csc_matrix, coo_matrix, lil_matrix)
+        data,
+        (
+            ndarray,
+            matrix,
+            csr_array,
+            csc_array,
+            coo_array,
+            lil_array,
+            csr_matrix,
+            csc_matrix,
+            coo_matrix,
+            lil_matrix,
+        ),
     ):
         from_incidence_matrix(data, create_using)
 
@@ -107,7 +129,7 @@ def convert_to_graph(H):
     """
 
     A = adjacency_matrix(H)  # This is unweighted by design
-    G = nx.from_scipy_sparse_matrix(A)
+    G = nx.from_scipy_sparse_array(A)
     G = nx.relabel_nodes(G, {i: node for i, node in enumerate(H.nodes)})
     return G
 
@@ -160,7 +182,19 @@ def convert_to_simplicial_complex(data, create_using=None):
         # edge dict in the form we need
         raise XGIError("Cannot generate SimplicialComplex from simplex dictionary")
     elif isinstance(
-        data, (ndarray, matrix, csr_matrix, csc_matrix, coo_matrix, lil_matrix)
+        data,
+        (
+            ndarray,
+            matrix,
+            csr_array,
+            csc_array,
+            coo_array,
+            lil_array,
+            csr_matrix,
+            csc_matrix,
+            coo_matrix,
+            lil_matrix,
+        ),
     ):
         # incidence matrix
         raise XGIError(
@@ -324,6 +358,32 @@ def from_bipartite_pandas_dataframe(
     return H
 
 
+def to_bipartite_pandas_dataframe(H):
+    """Create a two column dataframe from a hypergraph.
+
+    Parameters
+    ----------
+    H : Hypergraph or Simplicial Complex
+        A dataframe where specified columns list the node IDs
+        and the associated edge IDs
+
+    Returns
+    -------
+    Pandas Dataframe object
+        A two column dataframe
+
+    Raises
+    ------
+    XGIError
+        Raises an error if the user specifies invalid column names
+    """
+    data = []
+    for id1, members in H._node.items():
+        for id2 in members:
+            data.append([id1, id2])
+    return pd.DataFrame(data, columns=["Node ID", "Edge ID"])
+
+
 def from_incidence_matrix(d, create_using=None, nodelabels=None, edgelabels=None):
     """Create a hypergraph from an incidence matrix
 
@@ -355,7 +415,7 @@ def from_incidence_matrix(d, create_using=None, nodelabels=None, edgelabels=None
     incidence_matrix
     to_incidence_matrix
     """
-    I = coo_matrix(d)
+    I = coo_array(d)
     n, m = I.shape
 
     if nodelabels is None:
@@ -420,7 +480,7 @@ def to_incidence_matrix(H, sparse=True, index=False):
 
     Returns
     -------
-    numpy.ndarray or scipy csr_matrix
+    numpy.ndarray or scipy csr_array
         The incidence matrix
     dict
         The dictionary mapping indices to node IDs, if index is True
