@@ -10,7 +10,7 @@ import numpy as np
 from scipy.special import comb
 
 from ..classes import SimplicialComplex
-from .classic import empty_hypergraph, ring_lattice
+from .classic import empty_hypergraph, flag_complex_d2, ring_lattice
 
 __all__ = [
     "chung_lu_hypergraph",
@@ -290,8 +290,8 @@ def random_hypergraph(N, ps, seed=None):
     if (np.any(np.array(ps) < 0)) or (np.any(np.array(ps) > 1)):
         raise ValueError("All elements of ps must be between 0 and 1 included.")
 
-    nodes = range(N)  # list(G.nodes())
-    hyperedges = []  # hyperedges = list(G.edges())
+    nodes = range(N)
+    hyperedges = []
 
     for i, p in enumerate(ps):
         d = i + 1  # order, ps[0] is prob of edges (d=1)
@@ -304,8 +304,6 @@ def random_hypergraph(N, ps, seed=None):
 
         hyperedges += edges_to_add
 
-    hyperedges += [[i] for i in nodes]  # add singleton edges
-
     H = empty_hypergraph()
     H.add_nodes_from(nodes)
     H.add_edges_from(hyperedges)
@@ -358,7 +356,7 @@ def random_simplicial_complex(N, ps, seed=None):
         raise ValueError("All elements of ps must be between 0 and 1 included.")
 
     nodes = range(N)
-    simplices = [[i] for i in nodes]  # add singleton edges
+    simplices = []
 
     for i, p in enumerate(ps):
         d = i + 1  # order, ps[0] is prob of edges (d=1)
@@ -408,20 +406,7 @@ def random_flag_complex_d2(N, p, seed=None):
 
     G = nx.fast_gnp_random_graph(N, p, seed=seed)
 
-    nodes = G.nodes()
-    edges = list(G.edges())
-
-    # compute all triangles to fill
-    all_cliques = list(nx.enumerate_all_cliques(G))
-    triad_cliques = [tuple(x) for x in all_cliques if len(x) == 3]
-
-    simplices = edges + triad_cliques
-
-    S = SimplicialComplex()
-    S.add_nodes_from(nodes)
-    S.add_simplices_from(simplices)
-
-    return S
+    return flag_complex_d2(G)
 
 
 def random_flag_complex(N, p, max_order=2, seed=None):
